Sequence

Struct Sequence 

#[repr(transparent)]
pub struct Sequence<'arena, T> { pub nodes: Vec<'arena, T>, }
A sequence of AST nodes allocated in a bumpalo::Bump.

Fields

nodes: Vec<'arena, T>

Implementations

Source

impl<'arena, T> Sequence<'arena, T>

pub const fn new(inner: BVec<'arena, T>) -> Self

pub fn empty(arena: &'arena Bump) -> Self

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn get(&self, index: usize) -> Option<&T>

pub fn first(&self) -> Option<&T>

pub fn last(&self) -> Option<&T>

pub fn iter(&self) -> Iter<'_, T>

pub fn as_slice(&self) -> &[T]

Source

impl<'arena, T: HasSpan> Sequence<'arena, T>

pub fn first_span(&self) -> Option<Span>

pub fn last_span(&self) -> Option<Span>

pub fn span(&self, file_id: FileId, from: Position) -> Span

Compute the span covering the sequence, anchored at from.

Returns a zero-width span at from when the sequence is empty.