scan_identifier_length

Function scan_identifier_length 

pub fn scan_identifier_length(bytes: &[u8], offset: usize) -> usize
Scans an identifier starting at offset in the byte slice and returns the length.

Assumes the first byte is already validated as a start of identifier. Returns the total length of the identifier (including the first byte). Stops at the first byte that is not a valid identifier character.